{pkgs', ...}: let
  bashFktScript = import ./bash-fkt.nix {
    inherit pkgs';
  };
in
  pkgs'.writeShellScriptBin "run-extended-tests" ''

    source ${pkgs'.common}/bin/common
    ${bashFktScript}

    echo_header "Running extended tests"
    echo_hint "The command is executed in the current working directory and not in a nix derivation."
    cd_working_dir

    setup_go_env

    echo_step "Running tests"
    if ! ${pkgs'.go}/bin/go test -tags "runOnTask" -cover ./...
    then
      echo_fail "Failed to run tests"
      exit 1
    fi
    echo_ok "All tests passed"

    echo_step "Running benchmarks"
    if ! ${pkgs'.go}/bin/go test -tags "runOnTask,bench" -bench ./...
    then
      echo_fail "Failed to run benchmarks"
      exit 1
    fi
    echo_ok "Benchmarks passed"

    echo_step "Running race tests"
    if ! ${pkgs'.go}/bin/go test -tags "runOnTask,race" -race ./...
    then
      echo_fail "Failed to run race tests"
      exit 1
    fi
    echo_ok "race tests passed"

    echo_step "Running fuzz tests"
    if ! ${pkgs'.go}/bin/go test -tags "runOnTask,fuzz" -fuzz ./...
    then
      echo_fail "Failed to run fuzz tests"
      exit 1
    fi

    echo_ok "Fuzz tests passed"
    echo_ok "All tests passed"


  ''
